# Defined type wrapper for firmware
#
# $product = product name that you will be updating (see case statement for hint)
# $version = intended version number that the firmware should be on
# $path = path to the fiware binary OR the catalog.xml file for the idrac
# $force_restart = automatically restart the iDRAC server if reboots are needed (don't wait on user to reboot)
# $asm_hostname = the IP address of the appliance to get the firmware binaries from
#

define asm::firmware (
  $install_type    = "uri",
  $force_restart   = false,
  $decrypt         = false,
  $product         = undef,
  $version         = undef,
  $path            = undef,
  $asm_hostname    = undef,
  $server_firmware = undef,
  $instance_id     = undef,
  ) {

  $tftp_share = '/var/lib/tftpboot'

  $fw_type = $product ? {
    /^cmc.*/                   => 'cmc',
    /^dell_iom.*|^dell_ftos.*/ => 'ftos',
    /^server.*/                => 'bmc',
    /^dell_powerconnect.*/     => 'powerconnect',
    default                    => 'other'
  }

  case $fw_type {
    'cmc': {
      if $path =~ /\/var\/nfs\/firmware\/(.*)/ {
        $tftp_path = $1
      }
      cmc_fw_update {"update":
        ensure         => present,
        version        => $version,
        path           => $path,
        hostname       => $asm_hostname,
        copy_to_tftp   => [$tftp_share,$tftp_path]
      }
    }

    'bmc': {
      if $path =~ /\/var\/nfs\/firmware\/(.*)\// {
        $firmware_repo_id = $1
      }
      bmc_fw_ipmiflash { "update":
        bmc_firmware => exe_to_bmc_fw($server_firmware, $asm_hostname, $tftp_share, $firmware_repo_id),
        ensure       => present,
      }
    }

    'ftos': {
      if $path =~ /\/var\/nfs\/firmware\/(.*)/ {
        $tftp_path = $1
      }
      force10_firmwareupdate {"firmware_update":
        force        => false,
        url          => "tftp://$asm_hostname/$tftp_path",
        copy_to_tftp => [$tftp_share,$tftp_path],
        path         => $path,
      }
    }

    'powerconnect': {
      if $path =~ /\/var\/nfs\/firmware\/(.*)/ {
        $tftp_path = $1
      }
      $tftp_url = "tftp://$asm_hostname/$tftp_path"
      $imageurl = nfs_to_tftp($path,$tftp_url,$tftp_share)
      powerconnect_firmware { "firmware":
        imageurl    => $imageurl,
        forceupdate => 'true',
        saveconfig  => 'true'
      }
    }

    default : {
      fail("Firmware for product type: $fw_type not support")
    }
  }
}
