# == Definition: asm::idrac::initial_config
#
# Sets up initial onboard configuration for servers using idrac
#
# === Parameters:
#
# [*idrac_cred_id*]
#   String representing credential ID that needs to be set.
#
# [*idrac_network_type*]
#   String representing type of network to set. Applicable values: static or existing
#
# [*idrac_networks*]
#   Hash representing desired network configuration to be applied. Defaults to undefined value
#
# === Sample Usage:
#
# 1. Specify static IP with desired credentials for a server:
#
#  asm::idrac::initial_config { "rackserver-ABCD123":
#    idrac_network_type => "static",
#    idrac_networks => {
#      "staticNetworkConfiguration" => {
#        "gateway" => "172.27.0.1",
#        "subnet" => "255.255.0.0",
#        "primaryDns" => null,
#        "secondaryDns" => null,
#        "ipAddress" => "172.27.15.14"
#      }
#    },
#    idrac_cred_id => "abcdefgh1234"
#  }
#
# 2. Specify to use existing IP with desired credentials for a server:
#
#  asm::idrac::initial_config { "server-ABC":
#    idrac_network_type => "existing",
#    idrac_cred_id => "abcdefgh1234"
#  }
#
# === Copyright
#
# Copyright (C) 2016 Dell, Inc.
#
define asm::idrac::initial_config (
  $idrac_cred_id,
  $idrac_network_type,
  $idrac_networks = undef,
) {
  transport{ "idrac":
    name     => $name,
    options  => {},
    provider => device_file
  }->
  server_onboard { $name :
    credential => {
      "username" => asm_decrypt_username($idrac_cred_id),
      "password" => asm_decrypt_password($idrac_cred_id),
    },
    network_type => downcase($idrac_network_type),
    networks     => $idrac_networks,
    transport    => Transport["idrac"]
  }
}
